==> packageinstaller-pkglist-libre_0.1.4.tar.xz: packageinstaller-pkglist-libre/Latvian_LO_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
Latvian_LO_full
</name>

<description>  
   <am>Latvian Language Meta-Package for LibreOffice</am>
   <ar>Latvian Language Meta-Package for LibreOffice</ar>
   <bg>Latvian Language Meta-Package for LibreOffice</bg>
   <bn>Latvian Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Letó per LibreOffice</ca>
   <cs>Latvian Language Meta-Package for LibreOffice</cs>
   <da>Latvian Language Meta-Package for LibreOffice</da>
   <de>Lettisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Latvian</el>
   <en>Latvian Language Meta-Package for LibreOffice</en>
   <es>Meta-Paquete de idioma letón para LibreOffice</es>
   <et>Latvian Language Meta-Package for LibreOffice</et>
   <eu>Latvian Language Meta-Package for LibreOffice</eu>
   <fa>Latvian Language Meta-Package for LibreOffice</fa>
   <fil_PH>Latvian Language Meta-Package for LibreOffice</fil_PH>
   <fi>Latvian Language Meta-Package for LibreOffice</fi>
   <fr>Latvian Language Meta-Package for LibreOffice</fr>
   <he_IL>Latvian Language Meta-Package for LibreOffice</he_IL>
   <hi>Latvian Language Meta-Package for LibreOffice</hi>
   <hr>Latvian Language Meta-Package for LibreOffice</hr>
   <hu>Latvian Language Meta-Package for LibreOffice</hu>
   <id>Latvian Language Meta-Package for LibreOffice</id>
   <is>Latvian Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua lettone per LibreOffice</it>
   <ja_JP>Latvian Language Meta-Package for LibreOffice</ja_JP>
   <ja>Latvian Language Meta-Package for LibreOffice</ja>
   <kk>Latvian Language Meta-Package for LibreOffice</kk>
   <ko>Latvian Language Meta-Package for LibreOffice</ko>
   <lt>Latvian Language Meta-Package for LibreOffice</lt>
   <mk>Latvian Language Meta-Package for LibreOffice</mk>
   <mr>Latvian Language Meta-Package for LibreOffice</mr>
   <nb>Latvian Language Meta-Package for LibreOffice</nb>
   <nl>Lets Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Latvian Language Meta-Package for LibreOffice</pl>
   <pt_BR>Latvian Language Meta-Package for LibreOffice</pt_BR>
   <pt>Letão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Latvian Language Meta-Package for LibreOffice</ro>
   <ru>Latvian Language Meta-Package for LibreOffice</ru>
   <sk>Latvian Language Meta-Package for LibreOffice</sk>
   <sl>Latvijski jezikovni meta-paket za LibreOffice</sl>
   <sq>Latvian Language Meta-Package for LibreOffice</sq>
   <sr>Latvian Language Meta-Package for LibreOffice</sr>
   <sv>Lettländskt Språk Meta-Paket för LibreOffice</sv>
   <tr>Latvian Language Meta-Package for LibreOffice</tr>
   <uk>Latvian Language Meta-Package for LibreOffice</uk>
   <vi>Latvian Language Meta-Package for LibreOffice</vi>
   <zh_CN>Latvian Language Meta-Package for LibreOffice</zh_CN>
   <zh_TW>Latvian Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-lv
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-lv
libreoffice-gtk3
</uninstall_package_names>

</app>

==> packageinstaller-pkglist-libre_0.1.7.tar.xz: packageinstaller-pkglist-libre/Latvian_LO_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Latvian_LO_full
</name>

<description>
   <am>Latvian Language Meta-Package for LibreOffice</am>
   <ar>Latvian Language Meta-Package for LibreOffice</ar>
   <be>Latvian Language Meta-Package for LibreOffice</be>
   <bg>Latvian Language Meta-Package for LibreOffice</bg>
   <bn>Latvian Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Letó per LibreOffice</ca>
   <cs>Latvian Language Meta-Package for LibreOffice</cs>
   <da>Latvian Language Meta-Package for LibreOffice</da>
   <de>Lettisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Λετονικά</el>
   <en>Latvian Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma letón para LibreOffice</es_ES>
   <es>Metapaquete de idioma Letón para LibreOffice</es>
   <et>Latvian Language Meta-Package for LibreOffice</et>
   <eu>Latvian Language Meta-Package for LibreOffice</eu>
   <fa>Latvian Language Meta-Package for LibreOffice</fa>
   <fil_PH>Latvian Language Meta-Package for LibreOffice</fil_PH>
   <fi>Latvialainen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Méta-Paquet en langue lettone pour LibreOffice</fr_BE>
   <fr>Méta-Paquet en langue lettone pour LibreOffice</fr>
   <gl_ES>Letón Meta-paquete de Idioma para LibreOffice</gl_ES>
   <he_IL>Latvian Language Meta-Package for LibreOffice</he_IL>
   <hi>Latvian Language Meta-Package for LibreOffice</hi>
   <hr>Latvian Language Meta-Package for LibreOffice</hr>
   <hu>Latvian Language Meta-Package for LibreOffice</hu>
   <id>Latvian Language Meta-Package for LibreOffice</id>
   <is>Latvian Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua lettone per LibreOffice</it>
   <ja>LibreOffice用ラトビア語メタパッケージ</ja>
   <kk>Latvian Language Meta-Package for LibreOffice</kk>
   <ko>Latvian Language Meta-Package for LibreOffice</ko>
   <lt>Latvian Language Meta-Package for LibreOffice</lt>
   <mk>Latvian Language Meta-Package for LibreOffice</mk>
   <mr>Latvian Language Meta-Package for LibreOffice</mr>
   <nb_NO>Latvian Language Meta-Package for LibreOffice</nb_NO>
   <nb>Latvisk språkpakke for LibreOffice</nb>
   <nl_BE>Latvian Language Meta-Package for LibreOffice</nl_BE>
   <nl>Lets Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Łotewski meta-pakiet językowy dla LibreOffice</pl>
   <pt_BR>Letão Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Letão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Latvian Language Meta-Package for LibreOffice</ro>
   <ru>Latvian Language Meta-Package for LibreOffice</ru>
   <sk>Latvian Language Meta-Package for LibreOffice</sk>
   <sl>Latvijski jezikovni meta-paket za LibreOffice</sl>
   <sq>Latvian Language Meta-Package for LibreOffice</sq>
   <sr>Latvian Language Meta-Package for LibreOffice</sr>
   <sv>Lettländskt Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Latvian สำหรับ LibreOffice</th>
   <tr>LibreOffice için Letonca Dili Üst-Paketi</tr>
   <uk>Latvian Language Meta-Package for LibreOffice</uk>
   <vi>Latvian Language Meta-Package for LibreOffice</vi>
   <zh_CN>Latvian Language Meta-Package for LibreOffice</zh_CN>
   <zh_HK>Latvian Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Latvian Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-lv
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-l10n-lv
libreoffice-gtk3
</uninstall_package_names>

</app>
